@@ -143,7 +143,7 @@ class TestLsLl:
     @patch("gita.info.get_head", return_value="master")
     @patch(
         "gita.info._get_repo_status",
-        return_value=("dirty", "staged", "untracked", "diverged"),
+        return_value=("dirty", "staged", "untracked", "", "diverged"),
     )
     @patch("gita.info.get_commit_msg", return_value="msg")
     @patch("gita.info.get_commit_time", return_value="")
@@ -196,8 +196,11 @@ def test_clone_with_url(mock_run):
 
 
 @patch(
-    "gita.utils.parse_clone_config",
-    return_value=[["git@github.com:user/repo.git", "repo", "/a/repo"]],
+    "gita.io.parse_clone_config",
+    return_value=(
+        {"repo": {"url": "git@github.com:user/repo.git", "path": "/a/repo"}},
+        {},
+    ),
 )
 @patch("gita.utils.run_async", new=async_mock())
 @patch("subprocess.run")
@@ -217,8 +220,11 @@ def test_clone_with_config_file(*_):
 
 
 @patch(
-    "gita.utils.parse_clone_config",
-    return_value=[["git@github.com:user/repo.git", "repo", "/a/repo"]],
+    "gita.io.parse_clone_config",
+    return_value=(
+        {"repo": {"url": "git@github.com:user/repo.git", "path": "/a/repo"}},
+        {},
+    ),
 )
 @patch("gita.utils.run_async", new=async_mock())
 @patch("subprocess.run")
